# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from . import conf


default_app_config = 'djconfig.apps.DjConfig'

config = conf.config
register = conf.register
reload_maybe = conf.reload_maybe

__version__ = "0.5.3"
__all__ = ['config', 'register', 'reload_maybe']



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from . import conf

try:
    from django.utils.deprecation import MiddlewareMixin
except ImportError:  # Django < 1.10
    MiddlewareMixin = object


__all__ = ['DjConfigMiddleware', ]


class DjConfigMiddleware(MiddlewareMixin):
    """
    Populate the cache using the database.\
    Reload the cache *only* if it is not up\
    to date with the config model
    """
    def process_request(self, request):
        conf.reload_maybe()


# Backward compatibility
DjConfigLocMemMiddleware = DjConfigMiddleware



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.apps import AppConfig


class DjConfig(AppConfig):

    name = 'djconfig'
    verbose_name = "Config"
    label = 'djconfig'



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import io
import os
from setuptools import setup, find_packages


BASE_DIR = os.path.join(os.path.dirname(__file__))
URL = 'https://github.com/nitely/django-djconfig'
README = "For more info, go to: {}".format(URL)


def get_version(package):
    """Get version without importing the lib"""
    with io.open(os.path.join(BASE_DIR, package, '__init__.py'), encoding='utf-8') as fh:
        return [
            l.split('=', 1)[1].strip().strip("'").strip('"')
            for l in fh.readlines()
            if '__version__' in l][0]


# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-djconfig',
    version=get_version('djconfig'),
    description='DjConfig is a Django app for storing dynamic configurations.',
    author='Esteban Castro Borsani',
    author_email='ecastroborsani@gmail.com',
    long_description=README,
    url=URL,
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    license='MIT License',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
